"""Generated by update_sounds_list.py [2025-05-28 16:43]."""

SOUNDS_LIST = {
    "air_horn": 4,
    "air_horns": 9,
    "airboat": 7,
    "airport": 13,
    "aliens": 14,
    "amzn_sfx_airplane_takeoff_whoosh": 1,
    "amzn_sfx_army_march_clank_7x": 1,
    "amzn_sfx_army_march_large_8x": 1,
    "amzn_sfx_army_march_small_8x": 1,
    "amzn_sfx_baby_big_cry": 1,
    "amzn_sfx_baby_cry": 2,
    "amzn_sfx_baby_fuss": 1,
    "amzn_sfx_battle_group_clanks": 1,
    "amzn_sfx_battle_man_grunts": 1,
    "amzn_sfx_battle_men_grunts": 1,
    "amzn_sfx_battle_men_horses": 1,
    "amzn_sfx_battle_noisy_clanks": 1,
    "amzn_sfx_battle_yells_men": 1,
    "amzn_sfx_battle_yells_men_run": 1,
    "amzn_sfx_bear_groan_roar": 1,
    "amzn_sfx_bear_roar_grumble": 1,
    "amzn_sfx_bear_roar_small": 1,
    "amzn_sfx_beep_1x": 1,
    "amzn_sfx_bell_med_chime": 1,
    "amzn_sfx_bell_short_chime": 3,
    "amzn_sfx_bell_timer": 1,
    "amzn_sfx_bicycle_bell_ring": 1,
    "amzn_sfx_bird_chickadee_chirp_1x": 1,
    "amzn_sfx_bird_chickadee_chirps": 1,
    "amzn_sfx_bird_forest": 2,
    "amzn_sfx_bird_forest_short": 1,
    "amzn_sfx_bird_robin_chirp_1x": 1,
    "amzn_sfx_boing_long_1x": 1,
    "amzn_sfx_boing_med_1x": 1,
    "amzn_sfx_boing_short_1x": 1,
    "amzn_sfx_bus_drive_past": 1,
    "amzn_sfx_buzz_electronic": 1,
    "amzn_sfx_buzzer_loud_alarm": 1,
    "amzn_sfx_buzzer_small": 1,
    "amzn_sfx_car_accelerate": 2,
    "amzn_sfx_car_accelerate_noisy": 1,
    "amzn_sfx_car_click_seatbelt": 2,
    "amzn_sfx_car_close_door_1x": 2,
    "amzn_sfx_car_drive_past": 1,
    "amzn_sfx_car_honk_1x": 1,
    "amzn_sfx_car_honk_2x": 1,
    "amzn_sfx_car_honk_3x": 2,
    "amzn_sfx_car_honk_long_1x": 2,
    "amzn_sfx_car_into_driveway": 1,
    "amzn_sfx_car_into_driveway_fast": 1,
    "amzn_sfx_car_slam_door_1x": 1,
    "amzn_sfx_car_undo_seatbelt": 2,
    "amzn_sfx_cat_angry_meow_1x": 2,
    "amzn_sfx_cat_angry_screech_1x": 1,
    "amzn_sfx_cat_long_meow_1x": 1,
    "amzn_sfx_cat_meow_1x": 2,
    "amzn_sfx_cat_purr": 3,
    "amzn_sfx_cat_purr_meow": 1,
    "amzn_sfx_chicken_cluck": 1,
    "amzn_sfx_church_bell_1x": 5,
    "amzn_sfx_church_bells_ringing": 1,
    "amzn_sfx_clear_throat_ahem": 1,
    "amzn_sfx_clock_ticking": 1,
    "amzn_sfx_clock_ticking_long": 1,
    "amzn_sfx_copy_machine": 2,
    "amzn_sfx_cough": 4,
    "amzn_sfx_crow_caw_1x": 2,
    "amzn_sfx_crowd_applause": 5,
    "amzn_sfx_crowd_bar": 1,
    "amzn_sfx_crowd_bar_rowdy": 1,
    "amzn_sfx_crowd_boo": 3,
    "amzn_sfx_crowd_cheer_med": 1,
    "amzn_sfx_crowd_excited_cheer": 1,
    "amzn_sfx_dog_med_bark_1x": 3,
    "amzn_sfx_dog_med_bark_2x": 3,
    "amzn_sfx_dog_med_bark_growl": 1,
    "amzn_sfx_dog_med_growl_1x": 1,
    "amzn_sfx_dog_med_woof_1x": 1,
    "amzn_sfx_dog_small_bark_2x": 1,
    "amzn_sfx_door_open": 3,
    "amzn_sfx_door_shut": 2,
    "amzn_sfx_doorbell": 1,
    "amzn_sfx_doorbell_buzz": 1,
    "amzn_sfx_doorbell_chime": 2,
    "amzn_sfx_drinking_slurp": 1,
    "amzn_sfx_drum_and_cymbal": 2,
    "amzn_sfx_drum_comedy": 3,
    "amzn_sfx_earthquake_rumble": 2,
    "amzn_sfx_electric_guitar": 2,
    "amzn_sfx_electronic_beep": 3,
    "amzn_sfx_electronic_major_chord": 1,
    "amzn_sfx_elephant": 5,
    "amzn_sfx_elevator_bell_1x": 1,
    "amzn_sfx_elevator_open_bell": 1,
    "amzn_sfx_fairy_melodic_chimes": 1,
    "amzn_sfx_fairy_sparkle_chimes": 1,
    "amzn_sfx_faucet_drip": 3,
    "amzn_sfx_faucet_running": 3,
    "amzn_sfx_fireplace_crackle": 3,
    "amzn_sfx_fireworks": 1,
    "amzn_sfx_fireworks_firecrackers": 1,
    "amzn_sfx_fireworks_launch": 1,
    "amzn_sfx_fireworks_whistles": 2,
    "amzn_sfx_food_frying": 1,
    "amzn_sfx_footsteps": 1,
    "amzn_sfx_footsteps_muffled": 1,
    "amzn_sfx_ghost_spooky": 4,
    "amzn_sfx_glass_on_table": 1,
    "amzn_sfx_glasses_clink": 4,
    "amzn_sfx_horse_gallop_4x": 3,
    "amzn_sfx_horse_huff_whinny": 1,
    "amzn_sfx_horse_neigh": 1,
    "amzn_sfx_horse_neigh_low": 1,
    "amzn_sfx_horse_whinny": 3,
    "amzn_sfx_human_walking": 3,
    "amzn_sfx_jar_on_table_1x": 1,
    "amzn_sfx_kitchen_ambience": 1,
    "amzn_sfx_large_crowd_cheer": 3,
    "amzn_sfx_large_fire_crackling": 1,
    "amzn_sfx_laughter": 1,
    "amzn_sfx_laughter_giggle": 2,
    "amzn_sfx_lightning_strike": 2,
    "amzn_sfx_lion_roar": 3,
    "amzn_sfx_magic_blast_1x": 1,
    "amzn_sfx_monkey_calls_3x": 1,
    "amzn_sfx_monkey_chimp": 1,
    "amzn_sfx_monkeys_chatter": 1,
    "amzn_sfx_motorcycle_accelerate": 2,
    "amzn_sfx_motorcycle_engine_idle": 1,
    "amzn_sfx_motorcycle_engine_rev": 2,
    "amzn_sfx_musical_drone_intro": 2,
    "amzn_sfx_oars_splashing_rowboat": 1,
    "amzn_sfx_object_on_table_2x": 1,
    "amzn_sfx_ocean_wave_1x": 2,
    "amzn_sfx_ocean_wave_on_rocks_1x": 2,
    "amzn_sfx_ocean_wave_surf": 1,
    "amzn_sfx_people_walking": 2,
    "amzn_sfx_person_running": 3,
    "amzn_sfx_piano_note_1x": 1,
    "amzn_sfx_punch": 3,
    "amzn_sfx_rain": 3,
    "amzn_sfx_rain_on_roof": 1,
    "amzn_sfx_rain_thunder": 1,
    "amzn_sfx_rat_squeak_2x": 1,
    "amzn_sfx_rat_squeaks": 1,
    "amzn_sfx_raven_caw_1x": 1,
    "amzn_sfx_raven_caw_2x": 1,
    "amzn_sfx_restaurant_ambience": 2,
    "amzn_sfx_rooster_crow": 2,
    "amzn_sfx_scifi_air_escaping": 1,
    "amzn_sfx_scifi_alarm": 6,
    "amzn_sfx_scifi_alien_voice": 11,
    "amzn_sfx_scifi_boots_walking": 1,
    "amzn_sfx_scifi_close_large_explosion": 1,
    "amzn_sfx_scifi_door_open": 5,
    "amzn_sfx_scifi_engines_on": 2,
    "amzn_sfx_scifi_engines_on_large": 1,
    "amzn_sfx_scifi_engines_on_short_burst": 1,
    "amzn_sfx_scifi_explosion": 3,
    "amzn_sfx_scifi_explosion_2x": 1,
    "amzn_sfx_scifi_incoming_explosion": 1,
    "amzn_sfx_scifi_laser_gun_battle": 2,
    "amzn_sfx_scifi_laser_gun_fires": 6,
    "amzn_sfx_scifi_laser_gun_fires_large": 4,
    "amzn_sfx_scifi_long_explosion_1x": 1,
    "amzn_sfx_scifi_missile": 4,
    "amzn_sfx_scifi_motor_short_1x": 1,
    "amzn_sfx_scifi_open_airlock": 1,
    "amzn_sfx_scifi_radar_high_ping": 1,
    "amzn_sfx_scifi_radar_low": 1,
    "amzn_sfx_scifi_radar_medium": 1,
    "amzn_sfx_scifi_run_away": 2,
    "amzn_sfx_scifi_sheilds_up": 1,
    "amzn_sfx_scifi_short_low_explosion": 1,
    "amzn_sfx_scifi_small_whoosh_flyby": 1,
    "amzn_sfx_scifi_small_zoom_flyby": 1,
    "amzn_sfx_scifi_sonar_ping_3x": 1,
    "amzn_sfx_scifi_sonar_ping_4x": 1,
    "amzn_sfx_scifi_spaceship_flyby": 2,
    "amzn_sfx_scifi_timer_beep": 1,
    "amzn_sfx_scifi_zap_backwards": 1,
    "amzn_sfx_scifi_zap_electric": 2,
    "amzn_sfx_sheep_baa": 1,
    "amzn_sfx_sheep_bleat": 3,
    "amzn_sfx_silverware_clank": 3,
    "amzn_sfx_sirens": 1,
    "amzn_sfx_sleigh_bells": 2,
    "amzn_sfx_small_stream": 2,
    "amzn_sfx_sneeze": 2,
    "amzn_sfx_stream": 3,
    "amzn_sfx_strong_wind_desert": 1,
    "amzn_sfx_strong_wind_whistling": 3,
    "amzn_sfx_subway_leaving": 1,
    "amzn_sfx_subway_passing": 1,
    "amzn_sfx_subway_stopping": 1,
    "amzn_sfx_swoosh_cartoon_fast": 2,
    "amzn_sfx_swoosh_fast_1x": 1,
    "amzn_sfx_swoosh_fast_6x": 1,
    "amzn_sfx_test_tone": 1,
    "amzn_sfx_thunder_rumble": 2,
    "amzn_sfx_toilet_flush": 2,
    "amzn_sfx_trumpet_bugle": 4,
    "amzn_sfx_turkey_gobbling": 1,
    "amzn_sfx_typing_medium": 2,
    "amzn_sfx_typing_short": 2,
    "amzn_sfx_typing_typewriter": 1,
    "amzn_sfx_vacuum_off": 1,
    "amzn_sfx_vacuum_on": 1,
    "amzn_sfx_walking_in_mud": 2,
    "amzn_sfx_walking_in_snow": 1,
    "amzn_sfx_walking_on_grass": 3,
    "amzn_sfx_water_dripping": 1,
    "amzn_sfx_water_droplets": 2,
    "amzn_sfx_wind_strong_gusting": 1,
    "amzn_sfx_wind_whistling_desert": 1,
    "amzn_sfx_wings_flap_4x": 1,
    "amzn_sfx_wings_flap_fast": 1,
    "amzn_sfx_wolf_howl": 3,
    "amzn_sfx_wolf_young_howl": 1,
    "amzn_sfx_wooden_door": 1,
    "amzn_sfx_wooden_door_creaks_long": 2,
    "amzn_sfx_wooden_door_creaks_multiple": 1,
    "amzn_sfx_wooden_door_creaks_open": 1,
    "amzn_ui_sfx_gameshow_bridge": 2,
    "amzn_ui_sfx_gameshow_countdown_loop_32s_full": 1,
    "amzn_ui_sfx_gameshow_countdown_loop_64s_full": 1,
    "amzn_ui_sfx_gameshow_countdown_loop_64s_minimal": 1,
    "amzn_ui_sfx_gameshow_intro": 1,
    "amzn_ui_sfx_gameshow_negative_response": 3,
    "amzn_ui_sfx_gameshow_neutral_response": 3,
    "amzn_ui_sfx_gameshow_outro": 1,
    "amzn_ui_sfx_gameshow_player1": 1,
    "amzn_ui_sfx_gameshow_player2": 1,
    "amzn_ui_sfx_gameshow_player3": 1,
    "amzn_ui_sfx_gameshow_player4": 1,
    "amzn_ui_sfx_gameshow_positive_response": 3,
    "amzn_ui_sfx_gameshow_tally_negative": 1,
    "amzn_ui_sfx_gameshow_tally_positive": 1,
    "amzn_ui_sfx_gameshow_waiting_loop_30s": 1,
    "anchor": 13,
    "answering_machines": 13,
    "arcs_sparks": 15,
    "arrows_bows": 11,
    "baby": 13,
    "back_up_beeps": 9,
    "bars_restaurants": 16,
    "baseball": 10,
    "basketball": 9,
    "battles": 13,
    "beeps_tones": 15,
    "bell": 6,
    "bikes": 6,
    "billiards": 10,
    "board_games": 10,
    "body": 9,
    "boing": 3,
    "books": 11,
    "bow_wash": 11,
    "box": 10,
    "break_shatter_smash": 15,
    "breaks": 13,
    "brooms_mops": 15,
    "bullets": 12,
    "buses": 15,
    "buzz": 5,
    "buzz_hums": 15,
    "buzzers": 15,
    "buzzers_pistols": 15,
    "cables_metal": 13,
    "camera": 15,
    "cannons": 14,
    "car_alarm": 5,
    "car_alarms": 10,
    "car_cell_phones": 5,
    "carnivals_fairs": 9,
    "cars": 29,
    "casino": 5,
    "casinos": 5,
    "cellar": 4,
    "chimes": 14,
    "chimes_bells": 14,
    "chorus": 15,
    "christmas": 7,
    "church_bells": 9,
    "clock": 3,
    "cloth": 14,
    "concrete": 10,
    "construction": 15,
    "construction_factory": 13,
    "crashes": 14,
    "crowds": 24,
    "debris": 14,
    "dining_kitchens": 11,
    "dinosaurs": 15,
    "dripping": 7,
    "drops": 13,
    "electric": 5,
    "electrical": 15,
    "elevator": 2,
    "evolution_monsters": 15,
    "explosions": 14,
    "factory": 15,
    "falls": 13,
    "fax_scanner_copier": 15,
    "feedback_mics": 15,
    "fight": 9,
    "fire": 13,
    "fire_extinguisher": 13,
    "fireballs": 15,
    "fireworks": 15,
    "fishing_pole": 13,
    "flags": 12,
    "football": 3,
    "footsteps": 11,
    "futuristic": 45,
    "futuristic_ship": 14,
    "gameshow": 4,
    "gear": 14,
    "ghosts_demons": 15,
    "giant_monster": 15,
    "glass": 9,
    "glasses_clink": 4,
    "golf": 8,
    "gorilla": 10,
    "grenade_lanucher": 12,
    "griffen": 13,
    "gyms_locker_rooms": 8,
    "handgun_loading": 14,
    "handgun_shot": 13,
    "handle": 14,
    "hands": 12,
    "heartbeats_ekg": 13,
    "helicopter": 15,
    "high_tech": 15,
    "hit_punch_slap": 10,
    "hits": 23,
    "horns": 14,
    "horror": 15,
    "hot_tub_filling_up": 2,
    "human": 12,
    "human_vocals": 15,
    "hygene": 9,
    "ice_skating": 7,
    "ignitions": 15,
    "infantry": 14,
    "intro": 2,
    "jet": 15,
    "juggling": 3,
    "key_lock": 12,
    "kids": 9,
    "knocks": 15,
    "lab_equip": 13,
    "lacrosse": 2,
    "lamps_lanterns": 10,
    "leather": 9,
    "liquid_suction": 12,
    "locker_doors": 12,
    "machine_gun": 14,
    "magic_spells": 15,
    "medium_large_explosions": 13,
    "metal": 43,
    "modern_rings": 10,
    "money_coins": 6,
    "motorcycles": 11,
    "movement": 12,
    "moves": 10,
    "nature": 11,
    "oar_boat": 13,
    "pagers": 5,
    "paintball": 14,
    "paper": 16,
    "parachute": 12,
    "pay_phones": 13,
    "phone_beeps": 15,
    "pigmy_bats": 14,
    "pills": 11,
    "pour_water": 1,
    "power_up_down": 15,
    "printers": 14,
    "prison": 17,
    "public_space": 5,
    "racquetball": 7,
    "radios_static": 15,
    "rain": 10,
    "rc_airplane": 5,
    "rc_car": 14,
    "refrigerators_freezers": 12,
    "regular": 19,
    "respirator": 14,
    "rifle": 14,
    "roller_coaster": 10,
    "rollerskates_rollerblades": 5,
    "room_tones": 5,
    "ropes_climbing": 4,
    "rotary_rings": 13,
    "rowboat_canoe": 6,
    "rubber": 12,
    "running": 12,
    "sails": 14,
    "sand_gravel": 10,
    "screen_doors": 14,
    "screens": 14,
    "seats_stools": 9,
    "servos": 15,
    "shoes_boots": 7,
    "shotgun": 13,
    "shower": 2,
    "sink_faucet": 1,
    "sink_filling_water": 1,
    "sink_run_and_off": 1,
    "sink_water_splatter": 1,
    "sirens": 1,
    "skateboards": 11,
    "ski": 3,
    "skids_tires": 11,
    "sled": 4,
    "slides": 9,
    "small_explosions": 14,
    "snow": 12,
    "snowmobile": 5,
    "soldiers": 3,
    "splash_water": 11,
    "splashes_sprays": 14,
    "sports_whistles": 15,
    "squeaks": 13,
    "squeaky": 15,
    "stairs": 12,
    "steam": 14,
    "submarine_diesel": 10,
    "swing_doors": 4,
    "switches_levers": 15,
    "swords": 14,
    "tape": 13,
    "tape_machine": 14,
    "televisions_shows": 11,
    "tennis_pingpong": 11,
    "textile": 15,
    "throw": 7,
    "thunder": 13,
    "ticks": 18,
    "timer": 1,
    "toilet_flush": 2,
    "tone": 5,
    "tones_noises": 11,
    "toys": 15,
    "tractors": 10,
    "traffic": 11,
    "train": 10,
    "trucks_vans": 14,
    "turnstiles": 9,
    "typing": 10,
    "umbrella": 11,
    "underwater": 8,
    "vampires": 15,
    "various": 27,
    "video_tunes": 10,
    "volcano_earthquake": 3,
    "watches": 8,
    "water": 22,
    "water_running": 1,
    "werewolves": 11,
    "winches_gears": 14,
    "wind": 10,
    "wood": 24,
    "wood_boat": 6,
    "woosh": 4,
    "zap": 3,
    "zippers": 15,
}
